summaryrefslogtreecommitdiffstats
path: root/kig/misc/rect.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/rect.h')
-rw-r--r--kig/misc/rect.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kig/misc/rect.h b/kig/misc/rect.h
index a222d1ab..1fe0b071 100644
--- a/kig/misc/rect.h
+++ b/kig/misc/rect.h
@@ -24,12 +24,12 @@
#include "coordinate.h"
-#include <qrect.h>
+#include <tqrect.h>
#include <kdebug.h>
/**
* like Coordinate is a QPoint replacement with doubles, this is a
* QRect replacement with doubles...
*/
class Rect
{
@@ -103,7 +103,7 @@ public:
*/
Rect matchShape( const Rect& rhs, bool shrink = false ) const;
- QRect toQRect() const;
+ TQRect toQRect() const;
Coordinate bottomLeft() const;
Coordinate bottomRight() const;
Coordinate topLeft() const;
@@ -121,7 +121,7 @@ public:
Rect normalized() const;
friend kdbgstream& operator<<( kdbgstream& s, const Rect& t );
- static Rect fromQRect( const QRect& );
+ static Rect fromQRect( const TQRect& );
protected:
Coordinate mBottomLeft;
double mwidth;
@@ -24,12 +24,12 @@
#include <kdebug.h>
/**
- * like Coordinate is a QPoint replacement with doubles, this is a
- * QRect replacement with doubles...
+ * like Coordinate is a TQPoint replacement with doubles, this is a
+ * TQRect replacement with doubles...
*/
class Rect